@@ -1,8 +1,8 @@
 """
 This module implements a set of utilities for extracting features and
-train/testing :class:`revscoring.scorer_models.MLScorerModel` from the
-command-line.  When the revscoring python package is installed, a `revscoring`
-utility should be available from the commandline.  Run `revscoring -h` for more
+train/testing :class:`revscoring.Model` from the command-line.  When the
+revscoring python package is installed, a `revscoring` utility should be
+available from the commandline.  Run `revscoring -h` for more
 information:
 
 cv_train
@@ -13,6 +13,10 @@ extract
 +++++++
 .. automodule:: revscoring.utilities.extract
 
+fetch_text
+++++++++++
+.. automodule:: revscoring.utilities.fetch_text
+
 fit
 +++
 .. automodule:: revscoring.utilities.fit
@@ -25,10 +29,6 @@ score
 +++++
 .. automodule:: revscoring.utilities.score
 
-train_model
-+++++++++++
-.. automodule:: revscoring.utilities.train_model
-
 test_model
 ++++++++++
 .. automodule:: revscoring.utilities.test_model
